from setuptools import setup

setup(name='cnnftsp',
      version='1.0.3',
      description='CNN for TSP',
      author='Sikorski Philipp',
      author_email='philipp.sikorski@uni-jena.de',
      license='MIT',
      packages=['cnnfortsp'],
      zip_safe=False)